import argparse
import sys
from datetime import datetime
from pathlib import Path

from m3u_archive.m3u_archive_writer import M3UArchiveWriter


def main() -> None:
    """Add files specified in M3U files to an archive."""
    try:
        parser = argparse.ArgumentParser(
            description="Add files specified in M3U files to an archive.",
            formatter_class=argparse.MetavarTypeHelpFormatter,
        )

        parser.add_argument(
            "path", nargs="+", type=Path, help="M3U files to add to archive"
        )
        parser.add_argument(
            "-d",
            "--destination",
            type=Path,
            default=Path.cwd(),
            help="destination of the new archive (default: cwd)",
        )
        parser.add_argument(
            "-n",
            "--name",
            type=str,
            default=datetime.now().strftime("%Y-%m-%d_%H:%M:%S"),
            help="name of the resulting archive (default: current date and "
            "time)",
        )
        parser.add_argument(
            "-i",
            "--ignore",
            action="store_true",
            help="ignore any invalid or unknown lines",
        )

        args = parser.parse_args()

        new_archive = M3UArchiveWriter(
            args.path, args.name, args.destination, args.ignore
        )
        new_archive.write_archive()

    except Exception as e:
        print(str(e))
        sys.exit(2)


if __name__ == "__main__":
    main()
